# CHANGELOG

## [0.0.2] - 2022-11-09

- Feat: Implement a QGIS plugin with a simple toolbar
- Feat: Add map tool for selecting and drawing the reshape geometry
- Feat: Support complex calculation for the common segment
- Feat: Add snapping support when drawing the reshape geometry

## [0.0.1] - 2022-10-28

- Initial release: API for finding common segments and making reshape edits

[0.0.1]: https://github.com/nlsfi/segment-reshape-qgis-plugin/releases/tag/v0.0.1
[0.0.2]: https://github.com/nlsfi/segment-reshape-qgis-plugin/releases/tag/v0.0.2
